==> qmmp-0.8.6.tar.bz2: qmmp-0.8.6/src/plugins/Input/ffmpeg_legacy/translations/ffmpeg_legacy_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>DecoderFFmpegFactory</name>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="99"/>
        <source>FFmpeg Plugin</source>
        <translation>Suplemento FFmpeg</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="101"/>
        <source>FFmpeg Formats</source>
        <translation>Formatos FFmpeg</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="208"/>
        <source>About FFmpeg Audio Plugin</source>
        <translation>Sobre o suplemento FFmpeg Audio</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="210"/>
        <source>Qmmp FFmpeg Audio Plugin</source>
        <translation>Suplemento Qmmp FFmpeg Audio</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="211"/>
        <source>Compiled against libavformat-%1.%2.%3 and libavcodec-%4.%5.%6</source>
        <translation>Compilado com libavformat-%1.%2.%3 e libavcodec-%4.%5.%6</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="218"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFmpegMetaDataModel</name>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="48"/>
        <source>Length</source>
        <translation>Duração</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="49"/>
        <source>File size</source>
        <translation>Tamanho do ficheiro</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="49"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="50"/>
        <source>Bitrate</source>
        <translation>Taxa de dados</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="50"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="66"/>
        <source>Sample rate</source>
        <translation>Frequência</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="66"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="67"/>
        <source>Channels</source>
        <translation>Canais</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>FFmpeg Plugin Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Formats</source>
        <translation>Formatos</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Windows Media Audio</source>
        <translation>Windows Media Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source>Monkey&apos;s Audio (APE)</source>
        <translation>Monkey&apos;s Audio (APE)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>True Audio</source>
        <translation>True Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>ADTS AAC</source>
        <translation>ADTS AAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>MP3 (MPEG audio layer 3)</source>
        <translation>MP3 (MPEG audio layer 3)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>MPEG-4 AAC/ALAC</source>
        <translation>MPEG-4 AAC/ALAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>RealAudio 1.0/2.0</source>
        <translation>RealAudio 1.0/2.0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="110"/>
        <source>Shorten</source>
        <translation>Shorten</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>AC3/EAC</source>
        <translation>AC3/EAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <source>DTS/DTS-Core</source>
        <translation>DTS/DTS-Core</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Matroska Audio (Dolby TrueHD Lossless)</source>
        <translation>Matroska Audio (Dolby TrueHD Lossless)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="138"/>
        <source>VQF</source>
        <translation>VQF</translation>
    </message>
</context>
</TS>

==> qmmp-0.10.2.tar.bz2: qmmp-0.10.2/src/plugins/Input/ffmpeg_legacy/translations/ffmpeg_legacy_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>DecoderFFmpegFactory</name>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="101"/>
        <source>FFmpeg Plugin</source>
        <translation>Suplemento FFmpeg</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="103"/>
        <source>FFmpeg Formats</source>
        <translation>Formatos FFmpeg</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="210"/>
        <source>About FFmpeg Audio Plugin</source>
        <translation>Sobre o suplemento FFmpeg</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="212"/>
        <source>Qmmp FFmpeg Audio Plugin</source>
        <translation>Suplemento Qmmp FFmpeg Audio</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="213"/>
        <source>Compiled against libavformat-%1.%2.%3 and libavcodec-%4.%5.%6</source>
        <translation>Compilado com libavformat-%1.%2.%3 e libavcodec-%4.%5.%6</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="220"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFmpegMetaDataModel</name>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="48"/>
        <source>Length</source>
        <translation>Duração</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="49"/>
        <source>File size</source>
        <translation>Tamanho do ficheiro</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="49"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="50"/>
        <source>Bitrate</source>
        <translation>Taxa de dados</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="50"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="66"/>
        <source>Sample rate</source>
        <translation>Frequência</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="66"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="67"/>
        <source>Channels</source>
        <translation>Canais</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>FFmpeg Plugin Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Formats</source>
        <translation>Formatos</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Windows Media Audio</source>
        <translation>Windows Media Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source>Monkey&apos;s Audio (APE)</source>
        <translation>Monkey&apos;s Audio (APE)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>True Audio</source>
        <translation>True Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>ADTS AAC</source>
        <translation>ADTS AAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>MP3 (MPEG audio layer 3)</source>
        <translation>MP3 (MPEG audio layer 3)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>MPEG-4 AAC/ALAC</source>
        <translation>MPEG-4 AAC/ALAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>RealAudio 1.0/2.0</source>
        <translation>RealAudio 1.0/2.0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="110"/>
        <source>Shorten</source>
        <translation>Shorten</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>AC3/EAC</source>
        <translation>AC3/EAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <source>DTS/DTS-Core</source>
        <translation>DTS/DTS-Core</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Matroska Audio (Dolby TrueHD Lossless)</source>
        <translation>Matroska Audio (Dolby TrueHD Lossless)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="138"/>
        <source>VQF</source>
        <translation>VQF</translation>
    </message>
</context>
</TS>
